CounterView

Struct CounterView 

pub struct CounterView<F, M>
where F: MultiwriteNorFlash + 'static, M: RawMutex + 'static,
{ /* private fields */ }
View implementing [umsh_hal::CounterStore] on top of a shared FlashStore. Counters are stored as little-endian u32 values keyed by the caller-supplied context bytes (the MAC layer is expected to prefix them with mac.tx: / mac.rx:).

Implementations

Source

impl<F, M> CounterView<F, M>
where F: MultiwriteNorFlash + 'static, M: RawMutex + 'static,

pub fn new(storage: &'static FlashStore<F, M>) -> Self

Construct a counter view over the shared static storage.